/* From http://texturizer.net/firefox/adblock.html */

/* Block Ads v.2004-06-12 by Neil Jenkins
   Portions of this ruleset are derived from the ad blocking css by Joe Francis at:
   http://www.floppymoose.com/
   Some code also contributed by Mike Hokenson:
   http://www.gozer.org/mozilla/ad_blocking
*/ 

iframe[src*="/ad-"],
iframe[src*="/ad."],
iframe[src*="/ad/"],
iframe[src*="/ad_"],
iframe[src*="/adframe"],
iframe[src*="/ads"],
iframe[src*="/adv"],
iframe[src*="/adx"],
iframe[src*=".ad"],
iframe[src*="_Banner"],
iframe[src*="BET365"],
iframe[src*="/click"],
iframe[src*="?click"],
iframe[src*="googlesyndication"],
iframe[src*="promos"],
iframe[name="bsadframe"],
iframe[id="adFrame"],
iframe[id="splashFrame"],
img[src*="/ad-"],
img[src*="/ad."],
img[src*="/ad/"],
img[src*="/ad_"],
img[src*="/ads"],
img[src*="/adv"],
img[src*="/adx"],
img[src*=".ad"],
img[src*="_ad_"],
img[src*="/click"],
img[src*="?click"],
img[src*="Editorial_Promos"],
img[src*="/toms_skyscraper_"],
img[src$="images/logos/amazon_international.gif"],
img[src*="freshmeat.net/button.gif"],
img[src*="pic.geocities.com/images/"],
img[src*="i.imdb.com/Vpics/"],
img[src*="i.imdb.com/Photos/CMSIcons"],
img[src*="i.imdb.com/Icons/apix/"],
img[src*="i.imdb.com/Icons/kpix/"],
img[src*="i.imdb.com/apix/"],
img[src*="sportsbybrooks.com/farkbutton.gif"],
img[alt*="advert"],
img[alt*="Click Here To Visit Our Sponsor"],
img[alt*="Sponsored Links"],
img[name="fixedSpImg"],
a:link[href*="/ad-"] img,
a:link[href*="/ad."] img,
a:link[href*="/ad/"] img,
a:link[href*="/ad_"] img,
a:link[href*="/ads"] img,
a:link[href*="/adv"] img,
a:link[href*="/adx"] img,
a:link[href*=".ad"] img,
a:link[href*="/banner"] img,
a:link[href*="/click.cgi"] img,
a:link[href*="/clickcgi?"] img,
a:link[href*="/clickover"] img,
a:link[href*="/clickthr"] img,
a:link[href*="/click-"] img,
a:link[href*="=click"] img,
a:link[href*="?click"] img,
a:link[href*="/A="] img,
table table table[width="346"][height="280"],
table[class="metatable"],
table[id="RefAd"],
table[cellspacing="0"][width="160"][height="329"][bgcolor="#000000"],
table[cellpadding="5"][width="150"][style="border: 1px dashed rgb(221, 170, 170); background-color: rgb(236, 248, 255);"],
table[border="0"][height="600"][width="120"],
table[height="90"][cellspacing="0"][cellpadding="0"][width="728"][border="0"],
table[border="0"][cellpadding="3"][cellspacing="0"][height="40"][width="100%"],
table[border="0"][cellpadding="0"][cellspacing="4"][align="right"][width="20%"],
table[border="2"] td[valign="top"][bgcolor="#ffffff"] table[width="138"],
table[border="0"][cellpadding="1"][cellspacing="0"][width="626"][bgcolor="#6699cc"],
table[bordercolor="red"][height="225"][cellspacing="0"][cellpadding="0"][width="190"][bgcolor="white"][border="0"],
table[width="336"][border="0"][cellspacing="0"][cellpadding="0"][align="right"][style="margin-left: 10px; margin-bottom: 10px;"],
table[width="770"][border="0"] tr[valign="top"]
td[width="160"],
td[class="cnnNavAd"],
td[class="RHBarBody"],
td[class="sl-table"],
td[style="border-bottom: 1px solid rgb(204, 204, 204); padding: 7px 3px; background-color: rgb(255, 254, 249);"],
td span[class="aoltextad"],
form[name="frmLargeForm"],
form[action*="click_lx.cgi"],
form[action^="http://rd.yahoo.com/"],
form[action=""][name$="SoapCity"],
form[action=""][name^="728x90"],
form[action=""][name^="300x250"],
form[method="get"][action*="martindale"][name="MDH"],
embed[type="application/x-shockwave-flash"][src*="_Banner"],
embed[type="application/x-shockwave-flash"][src*="/ad"],
embed[type="application/x-shockwave-flash"][href*="/ad"],
embed[type="application/x-shockwave-flash"][src*=".ad"],
embed[type="application/x-shockwave-flash"][href*=".ad"],
embed[type="application/x-shockwave-flash"][src*="?click"],
embed[type="application/x-shockwave-flash"][href*="?click"],
embed[type="application/x-shockwave-flash"][src*="/click"],
embed[type="application/x-shockwave-flash"][href*="/click"],
embed[type="application/x-shockwave-flash"][href*="promos"],
embed[type="application/x-shockwave-flash"][href*="=click"],
embed[type="application/x-shockwave-flash"][href*="redirect"],
embed[type="application/x-shockwave-flash"][href*="/A="],
embed[type="application/x-shockwave-flash"][name*="advert"],
embed[type="application/x-shockwave-flash"][name*="banner"],
div[id="adstrip"],
div[id*="advert"],
div[id="dropin"],
div[id="dwindow"],
div[id="dcv_EchangeLay"],
div[id="mntl"],
div[id*="popup"],
div[id="quack"],
div[id="splashLayer"],
div[id*="sponsor"],
div[id="yschsec"],
div[class="ovt"],
div#contextualLinks,
div[style="border: 1px solid rgb(221, 221, 221); padding: 5px; background-color: rgb(255, 255, 255);"],
object[id="widgeth"],
*[class="ad"],
*[class*="eSext"],
*[name*="klipad"],
*[style*="/ads/"],
*[id*="popover_"],
*[src*="120x80"],
*[src*="?ad"],
*[src*="-ad-"],
*[src*="/adimage"],
*[src*="/adimg"],
*[src*="advert"],
*[src*="=click"],
*[src*="banners."],
*[src*="banner_ads"],
*[src*="/images/dinkus/more-arrow-lo.gif"],
*[src*="/javaImages/ec/"],
*[src*="/offer"],
*[src*="/puffboxes/"],
*[src*="/sponsors/"],
*[src*="_sponsor_"],
*[src*="/us.yimg.com/a/ya"],
*[src*=".adbutler.de"],
*[src*=".nedstatbasic.net"],
*[src*=".tradedoubler.com"],
*[src*=".travelocity./Sponsor_gifs/"],
*[src*="a.consumer.net"],
*[src*="bannermania.nom.pl"],
*[src*="cash4banner.com"],
*[src*="crazypopups.com"],
*[src*="hit-now.com"],
*[src*="hitbox.com"],
*[src*="img.thebugs.ws"],
*[src*="kinghost.com/ban/"],
*[src*="klipmart"],
*[src*="popupad.net/ats/"],
*[src*="public"][src*="ad"],
*[src*="/publicidad/"],
*[src*="qkimg.net"],
*[src*="qksrv.net"],
*[src*="rcm-images.amazon.com"],
*[src*="rcm.amazon.com"],
*[src*="salon.com/Creatives"],
*[src*="sexcounter."],
*[src*="sideads/"],
*[src*="statse.webtrendslive.com"],
*[href*="logging.to"],
*[href*="/referral/"],
*[href*="tryaol"],
*[href*="websponsors"],
*[src*="banman.asp"],
*[href*="banman.asp"],
*[src*="bannerman"],
*[href*="bannerman"],
*[src*="?banner"],
*[href*="?banner"],
*[src*="/banner/"],
*[href*="/banner/"],
*[src*="/jump/"],
*[href*="/jump/"],
*[src*="adfarm"],
*[href*="adfarm"],
*[src*="advertising.com"],
*[href*="advertising.com"],
*[src*="ar.atwola.com"],
*[href*="ar.atwola.com"],
*[src*="atdmt.com"],
*[href*="atdmt.com"],
*[src*="bluestreak.com"],
*[href*="bluestreak.com"],
*[src*="clickxchange.com"],
*[href*="clickxchange.com"],
*[src*="doubleclick"],
*[href*="doubleclick"],
*[src*="falkag.net"],
*[href*="falkag.net"],
*[src*="fastclick.com"],
*[href*="fastclick.com"],
*[src*="mediaplex"],
*[href*="mediaplex"],
*[src*="netdirect.nl"],
*[href*="netdirect.nl"],
*[src*="spinbox."],
*[href*="spinbox."],
*[src*="tradedoubler.com"],
*[href*="tradedoubler.com"],
*[src*="transfer.go"],
*[href*="transfer.go"],
*[src*=".tribalfusion"],
*[href*=".tribalfusion"],
*[src*="valueclick"],
*[href*="valueclick"],
*[src*="http://216.92.211.171/"],
*[href*="http://216.92.211.171/"],
*[src*="http://216.92.21.16/"],
*[href*="http://216.92.21.16/"] {
        display: none /*!important*/;
}

img[src*=".advance"],
img[src*="/click_"],
img[src*="/cnn/images/clickability/"],
img[src*="/logo2.m"],
img[src$="/banners/com000.jpg"],
a:link[href*=".add"] img,
a:link[href*="admin"] img,
a:link[href*="adobe"] img,
a:link[href*=".adp"] img,
a:link[href*="/advance"] img,
a:link[href*="click.mp3"] img,
a:link[href*="/imgres?imgurl="] img,
a:link[href*=":head"] img,
a:link[href*="http://nettracker."] img,
embed[type="application/x-shockwave-flash"][src*="gallery"] {
        display: inline /*!important*/;
}
